@@ -7,7 +7,7 @@ import sys
 import textwrap
 from pathlib import Path
 from typing import Any
-from unittest.mock import Mock
+from unittest.mock import Mock, patch
 
 import pytest
 import websockets
@@ -33,6 +33,7 @@ from home_assistant_streamdeck_yaml import (
     _keys,
     _light_page,
     _named_to_hex,
+    _on_press_callback,
     _render_jinja,
     _states,
     _to_filename,
@@ -498,8 +499,9 @@ async def test_handle_key_press_toggle_light(
     config: Config,
 ) -> None:
     """Test handle_key_press toggle light."""
-    key = 0
-    await _handle_key_press(websocket_mock, state, config, key, mock_deck)
+    button = config.button(0)
+    assert button is not None
+    await _handle_key_press(websocket_mock, state, config, button, mock_deck)
 
     websocket_mock.send.assert_called_once()
     send_call_args = websocket_mock.send.call_args.args[0]
@@ -518,8 +520,9 @@ async def test_handle_key_press_next_page(
     config: Config,
 ) -> None:
     """Test handle_key_press next page."""
-    key = 14
-    await _handle_key_press(websocket_mock, state, config, key, mock_deck)
+    button = config.button(14)
+    assert button is not None
+    await _handle_key_press(websocket_mock, state, config, button, mock_deck)
 
     # No service should be called
     websocket_mock.send.assert_not_called()
@@ -544,7 +547,7 @@ async def test_button_with_target(
     _button = config.button(0)
     assert _button is not None
     assert _button.service == "media_player.join"
-    await _handle_key_press(websocket_mock, {}, config, 0, mock_deck)
+    await _handle_key_press(websocket_mock, {}, config, _button, mock_deck)
     # Check that the send method was called with the correct payload
     called_payload = json.loads(websocket_mock.send.call_args.args[0])
     expected_payload = {
@@ -1045,18 +1048,67 @@ def test_icon_failed_icon() -> None:
 
 async def test_delay() -> None:
     """Test the delay."""
-    button = Button(delay=2)
+    button = Button(delay=0.1)
     assert not button.is_sleeping()
     assert button.maybe_start_or_cancel_timer()
     await asyncio.sleep(0)  # TODO: figure out why this is needed
     assert button._timer is not None
     assert button._timer.is_sleeping
     assert button.is_sleeping()
-    image = button.render_icon({})
-    image.save("test.png")
+    _ = button.render_icon({})
+    await asyncio.sleep(0.1)
+    assert not button.is_sleeping()
 
 
 def test_to_markdown_table() -> None:
     """Test to_markdown_table for docs."""
     table = Button.to_markdown_table()
     assert isinstance(table, str)
+
+
+async def test_anonymous_page(
+    mock_deck: Mock,
+    websocket_mock: Mock,
+    state: dict[str, dict[str, Any]],
+) -> None:
+    """Test that the anonymous page works."""
+    home = Page(
+        name="home",
+        buttons=[Button(special_type="go-to-page", special_type_data="anon")],
+    )
+    anon = Page(
+        name="anon",
+        buttons=[Button(text="yolo"), Button(text="foo", delay=0.1)],
+    )
+    config = Config(pages=[home], anonymous_pages=[anon])
+    assert config.current_page_index == 0
+    assert config._detached_page is None
+    assert config.to_page("anon") == anon
+    assert config._detached_page is not None
+    assert config.current_page() == anon
+    button = config.button(0)
+    assert button.text == "yolo"
+    press = _on_press_callback(websocket_mock, state, config)
+    # Click the button
+    await press(mock_deck, 0, key_pressed=True)
+    # Should now be the button on the first page
+    button = config.button(0)
+    assert button.special_type == "go-to-page"
+    # Back to anon page
+    assert config.to_page("anon") == anon
+    # Click the delay button
+    button = config.button(1)
+    assert button.text == "foo"
+    await press(mock_deck, 1, key_pressed=True)
+    # Should now still be the button because of the delay
+    assert button.text == "foo"
+    assert config._detached_page is not None
+    assert config.current_page() == anon
+    with patch("home_assistant_streamdeck_yaml.update_all_key_images") as mock:
+        await asyncio.sleep(0.15)  # longer than delay should then switch to home
+        mock.assert_called_once()
+    assert config._detached_page is None
+    assert config.current_page() == home
+    # Should now be the button on the first page
+    button = config.button(0)
+    assert button.special_type == "go-to-page"
